<?php
/**
 * Template: Event List Template
 *
 * This template renders each individual event in the events list.
 * To customize, copy this file to your-theme/vizou-events/vizou-events-list.php
 *
 * Available template tags:
 * - vizou_event_date() - Displays the event's start date
 * - vizou_event_end_date() - Displays the event's end date (for multi-day events)
 * - vizou_event_time() - Displays the event's time
 * - vizou_event_artist() - Displays the event's artist with optional link
 * - vizou_event_venue() - Displays the event's venue with optional link
 * - vizou_venue_street(), vizou_venue_city(), vizou_venue_province(), vizou_venue_country() - Address parts
 * - vizou_event_notes() - Displays the event description/notes
 * - vizou_event_status() - Displays the event status (if not "Active")
 * - vizou_event_tickets_link() - Displays the tickets button with link
 *
 * @package Vizou_Events_Manager
 * @since 0.1.5
 */

// Exit if accessed directly
if (!defined('ABSPATH')) exit;
?>

<p class="hide">Default events list template</p>
 
    <!-- BEGIN EVENT -->
    <div class="<?php echo esc_attr(implode(' ', array_map('sanitize_html_class', $classes))); ?>">

        <div class="left">

        <!-- DATE, TIME -->
            <p class="event-date">
                <?php 
                // Get both dates to determine if this is a multi-day event
                $start_date = vizou_event_date(null, false);
                $end_date = vizou_event_end_date(null, false);
                
                // Output date or date range appropriately
                echo esc_html($start_date);
                
                if (!empty($end_date)) {
                    echo ' - ' . esc_html($end_date);
                }
                ?>

                <?php if (vizou_event_time()): ?>
                    <span class="event-time"><?php vizou_event_time(); ?></span>
                <?php endif; ?>
            </p>

            <!-- TITLE (VENUE, ARTIST) -->
            <h3>
                <?php 
                // Display format depends on the setting
                $display_format = Vizou_Events_Settings::get_option('display_format');
                
                if ($display_format === 'artist_first') {
                    // Artist first
                    vizou_event_artist();
                    echo ' / <span class="event-venue">';
                    vizou_event_venue();
                    echo '</span>';
                } else {
                    // Venue first (default)
                    vizou_event_venue();
                    echo ' / <span class="event-artist">';
                    vizou_event_artist();
                    echo '</span>';
                }
                ?>
            </h3>

            <!-- LOCATION -->
            <p class="event-details">
                <span class="event-address">
                    <?php if (vizou_venue_street(null, false)): ?>
                        <span class="event-street"><?php vizou_venue_street(); ?>, </span>
                    <?php endif; ?>
                    
                    <?php if (vizou_venue_city(null, false)): ?>
                        <span class="event-city"><?php vizou_venue_city(); ?></span>
                    <?php endif; ?>
                    
                    <?php if (vizou_venue_province(null, false)): ?>
                        , <span class="event-province"><?php vizou_venue_province(); ?></span>
                    <?php endif; ?>
                    
                    <?php if (vizou_venue_country(null, false)): ?>
                        <span class="event-country"> (<?php vizou_venue_country(); ?>)</span>
                    <?php endif; ?>
                </span>

                <!-- NOTES -->
                <?php if (vizou_event_notes(null, false)): ?>
                    <span class="event-notes">
                        <?php vizou_event_notes(); ?>
                    </span>
                <?php endif; ?>

                <!-- STATUS -->
                <?php vizou_event_status(); ?>

                <?php edit_post_link(esc_html__('Edit', 'vizou-events-manager'), '', ''); ?>
            </p>

        </div>

        <div class="right">

        <!-- THUMBNAIL -->
            <?php if ((function_exists('has_post_thumbnail')) && (has_post_thumbnail())): ?>
            <a href="<?php echo esc_url($thumb[0]); ?>" title="<?php echo esc_attr(get_the_title()); ?>">
                <img class="event-thumb" 
                    src="<?php echo esc_url($thumb[0]); ?>" 
                    width="<?php echo esc_attr($thumb[1]); ?>" 
                    height="<?php echo esc_attr($thumb[2]); ?>" 
                    alt="<?php echo esc_attr($thumb_alt); ?>"
                    loading="lazy"/>
            </a>
            <?php endif; ?>

        <!-- TICKETS -->
            <p class="event-tickets">
                <?php vizou_event_tickets_link(); ?>
            </p>

        </div>
    </div>